@@ -896,7 +896,7 @@ KDecoration* GlowClientGlobals::createDecoration( KDecorationBridge* bridge )
 } // end of namespace
 
 extern "C"
-KDE_EXPORT KDecorationFactory* create_factory()
+TDE_EXPORT KDecorationFactory* create_factory()
 {
 	return Glow::GlowClientGlobals::instance();
 }
